@@ -86,7 +86,7 @@
 #define KNEWSTUFF_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KNEWSTUFF_NO_DEPRECATED
-#  define KNEWSTUFF_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55b00
+#  define KNEWSTUFF_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55d00
 #endif
 #ifdef KNEWSTUFF_NO_DEPRECATED_WARNINGS
 #  define KNEWSTUFF_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KNEWSTUFF_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KNEWSTUFF_DEPRECATED_WARNINGS_SINCE KNEWSTUFF_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KNEWSTUFF_DEPRECATED_WARNINGS_SINCE 0x55b00
+#    define KNEWSTUFF_DEPRECATED_WARNINGS_SINCE 0x55d00
 #  endif
 #endif
 
@@ -228,7 +228,7 @@
 #define KNEWSTUFF_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KNEWSTUFF_NO_DEPRECATED
-#  define KNEWSTUFF_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55b00
+#  define KNEWSTUFF_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55d00
 #endif
 #ifdef KNEWSTUFF_NO_DEPRECATED_WARNINGS
 #  define KNEWSTUFF_DEPRECATED_WARNINGS_SINCE 0
@@ -238,7 +238,7 @@
 #  ifdef KNEWSTUFF_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KNEWSTUFF_DEPRECATED_WARNINGS_SINCE KNEWSTUFF_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KNEWSTUFF_DEPRECATED_WARNINGS_SINCE 0x55b00
+#    define KNEWSTUFF_DEPRECATED_WARNINGS_SINCE 0x55d00
 #  endif
 #endif
 
